MusicTrack class

Constructors

MusicTrack({required String id, required String uri, required String title, required String? artist, required String album, required Duration duration, required String? artUri, String protocolInfo = 'http-get:*:*:*'})
const

Properties

album String
final
artist String?
final
artUri String?
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
protocolInfo String
Defaults to a fully wildcarded http-get entry. Renderers that match strictly on content format do better with a concrete MIME type, e.g. http-get:*:audio/mpeg:*. REQUIRED
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
uri String
final

Methods

describeFields() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toXml() String

Operators

operator ==(Object other) bool
The equality operator.
inherited