protocolInfo property
Defaults to a fully wildcarded http-get entry. Renderers that match
strictly on content format do better with a concrete MIME type, e.g.
http-get:*:audio/mpeg:*. REQUIRED
Implementation
final String protocolInfo;
Defaults to a fully wildcarded http-get entry. Renderers that match
strictly on content format do better with a concrete MIME type, e.g.
http-get:*:audio/mpeg:*. REQUIRED
final String protocolInfo;